==> genometools-1.4.0.tar.gz: genometools-1.4.0/src/match/rdj-revcompl-def.h <==
/*
  Copyright (c) 2009-2011 Giorgio Gonnella <gonnella@zbh-uni-hamburg.de>
  Copyright (c) 2009-2011 Center for Bioinformatics, University of Hamburg

  Permission to use, copy, modify, and distribute this software for any
  purpose with or without fee is hereby granted, provided that the above
  copyright notice and this permission notice appear in all copies.

  THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
  WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
  MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
  ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
  WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
  ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
  OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
*/

#ifndef RDJ_REVCOMPL_DEF_H
#define RDJ_REVCOMPL_DEF_H

/* correct seqnum and seqdirect variables if in revcompl range */
#define GT_READJOINER_CORRECT_REVCOMPL(SEQNUM,FIRSTREVCOMPL,NOFSEQ,SEQDIRECT)\
        if ((FIRSTREVCOMPL) > 0 && (SEQNUM) >= (FIRSTREVCOMPL))\
        {\
          gt_assert((SEQNUM) <= ((NOFSEQ)-1));\
          (SEQNUM) = ((NOFSEQ)-1)-(SEQNUM);\
          (SEQDIRECT) = false;\
        }\
        else (SEQDIRECT) = true

#define GT_READJOINER_READNUM(SEQNUM,FIRSTREVCOMPL,NOFSEQ)\
        (((FIRSTREVCOMPL) > 0 && (SEQNUM) >= (FIRSTREVCOMPL)) \
         ? (((NOFSEQ)-1)-(SEQNUM)) : (SEQNUM))

/* in revcompl mode the data would be output twice without this;
   e.g. 2 revcompl have same overlap that 2 direct sequences;
   convention: either are both direct, or the one with higher seqnum
   is allowed to be revcompl; this macro allows to skip other cases */

#define GT_READJOINER_IS_CORRECT_REVCOMPL_CASE(SN,SD,PN,PD)\
        (\
          ((SD) && (PD)) ||\
          ((SN) == (PN) && !(!(SD) && !(PD))) ||\
          ((SD) && !(PD) && (PN) > (SN)) ||\
          (!(SD) && (PD) && (PN) < (SN))\
        )

#endif

==> genometools-1.6.2.tar.gz: genometools-1.6.2/src/match/rdj-revcompl-def.h <==
/*
  Copyright (c) 2009-2011 Giorgio Gonnella <gonnella@zbh-uni-hamburg.de>
  Copyright (c) 2009-2011 Center for Bioinformatics, University of Hamburg

  Permission to use, copy, modify, and distribute this software for any
  purpose with or without fee is hereby granted, provided that the above
  copyright notice and this permission notice appear in all copies.

  THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
  WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
  MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
  ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
  WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
  ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
  OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
*/

#ifndef RDJ_REVCOMPL_DEF_H
#define RDJ_REVCOMPL_DEF_H

/* correct seqnum and seqdirect variables if in revcompl range */
#define GT_READJOINER_CORRECT_REVCOMPL(SEQNUM,FIRSTREVCOMPL,NOFSEQ,SEQDIRECT)\
        if ((FIRSTREVCOMPL) > 0 && (SEQNUM) >= (FIRSTREVCOMPL))\
        {\
          gt_assert((SEQNUM) <= ((NOFSEQ)-1));\
          (SEQNUM) = ((NOFSEQ)-1)-(SEQNUM);\
          (SEQDIRECT) = false;\
        }\
        else (SEQDIRECT) = true

#define GT_READJOINER_READNUM(SEQNUM,FIRSTREVCOMPL,NOFSEQ)\
        (((FIRSTREVCOMPL) > 0 && (SEQNUM) >= (FIRSTREVCOMPL)) \
         ? (((NOFSEQ)-1)-(SEQNUM)) : (SEQNUM))

/* in revcompl mode the data would be output twice without this;
   e.g. 2 revcompl have same overlap that 2 direct sequences;
   convention: either are both direct, or the one with higher seqnum
   is allowed to be revcompl; this macro allows one to skip other cases */

#define GT_READJOINER_IS_CORRECT_REVCOMPL_CASE(SN,SD,PN,PD)\
        (\
          ((SD) && (PD)) ||\
          ((SN) == (PN) && !(!(SD) && !(PD))) ||\
          ((SD) && !(PD) && (PN) > (SN)) ||\
          (!(SD) && (PD) && (PN) < (SN))\
        )

#endif
